@@ -5,7 +5,7 @@ Created on Fri Jan 13 18:59:17 2023
 @author: Administrator
 """
 import ntplib,datetime,sudo
-def __r(url):
+def __r():
     c = ntplib.NTPClient()
     
     hosts = ['edu.ntp.org.cn', 'tw.ntp.org.cn', 'us.ntp.org.cn', 'cn.pool.ntp.org', 'jp.ntp.org.cn']
@@ -40,6 +40,7 @@ def __r(url):
     
     eval(r"os.system('date %s && time %s' % (_date, _time))")
     print("同步后时间:", str(datetime.datetime.now())[:22])
-    class ct(url):
-        def __init__(url):
-            sudo.sudopy(__r(url))
\ No newline at end of file
+class ct():
+    def __init__(self):
+        sudo.sudopy(__r())
+ct()
\ No newline at end of file
