@@ -20,15 +20,14 @@ def powershell(file, o):
     return False
 
 
-def cmd(command):
+def cmd(command,else_do=r'print("失败")'):
     subp = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE,
                             stderr=subprocess.PIPE, encoding="utf-8")
     subp.wait()
     if subp.poll() == 0:
-        print(subp.communicate()[1])
+        print('DONE.')
     else:
-        print("失败")
-
+        exec(else_do)
 
 # 如果报错，说禁止执行脚本，是因为没有权限，所以，把上面的一行代码换成
 #args=[r"C:\WINDOWS\system32\WindowsPowerShell\v1.0\powershell.exe","-ExecutionPolicy","Unrestricted", r"D:\jzhou\test_ping.ps1",ip]
